<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Φίλτρο:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Επιλογή της γραμματοσειράς τερματικού</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Γραμματοσειρά:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Μέγεθος:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Σελιδοδείκτες</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Πιέστε «%1» για εμφάνιση του τερματικού.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Επόμενη καρτέλα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Προηγούμενη καρτέλα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Move Tab &amp;Left</source>
        <translation>Μετακίνηση της καρτέλας αρι&amp;στερά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Move Tab &amp;Right</source>
        <translation>Μετακίνηση της καρτέλας &amp;δεξιά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Εκκαθάριση του ενεργού τερματικού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Keep window open when it loses focus</source>
        <translation>Διατήρηση του παραθύρου ανοιχτό κατά την απώλεια της εστίασης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Προηγούμενη καρτέλα στο ιστορικό</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Επόμενη καρτέλα στο ιστορικό</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Tab</source>
        <translation>Καρτέλα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Go to</source>
        <translation>Μετάβαση σε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Split &amp;View Top-Bottom</source>
        <translation>Διαχωρισμός &amp;Προβολή Πάνω-Κάτω</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Split Vie&amp;w Left-Right</source>
        <translation>Διαχωρισμός &amp;Προβολή Αριστερά-Δεξιά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>&amp;Close Subterminal</source>
        <translation>&amp;Κλείσιμο του υποτερματικού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Άνω υποτερματικό</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Κάτω υποτερματικό</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>L&amp;eft Subterminal</source>
        <translation>Α&amp;ριστερό υποτερματικό</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Δεξί υποτερματικό</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Copy &amp;Selection</source>
        <translation>&amp;Αντιγραφή της επιλογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Paste Clip&amp;board</source>
        <translation>Επικόλληση του &amp;προχείρου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>Paste S&amp;election</source>
        <translation>Επικόλληση της επι&amp;λογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Zoom &amp;in</source>
        <translation>Μεγέ&amp;θυνση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;Σμίκρυνση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Zoom rese&amp;t</source>
        <translation>Επαναφορά της εσ&amp;τίασης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>&amp;Find...</source>
        <translation>Ανα&amp;ζήτηση...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Handle history...</source>
        <translation>Διαχείριση ιστορικού...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>&amp;Save Session</source>
        <translation>Απο&amp;θήκευση της συνεδρίας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Φόρτωση συνεδρίας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>&amp;Toggle Menu</source>
        <translation>Ε&amp;ναλλαγή εμφάνισης του μενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Rename session</source>
        <translation>Μετονομασία της συνεδρίας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Νέα καρτέλα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Νέα καρτέλα από προρύ&amp;θμιση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;Τερματικό</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;Οριζόντια τερματικά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;Κάθετα τερματικά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 Τερματι&amp;κά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Κλείσιμο της καρτέλας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>&amp;New Window</source>
        <translation>&amp;Νέο παράθυρο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Προτιμήσεις...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>&amp;Quit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>&amp;Hide Window Borders</source>
        <translation>Απόκρυ&amp;ψη του περιγράμματος του παραθύρου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Show Tab Bar</source>
        <translation>Εμφάνιση της &amp;γραμμής καρτελών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Toggle Bookmarks</source>
        <translation>Εναλλαγή σελιδοδεικτών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Βάση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>&amp;Top</source>
        <translation>&amp;Κορυφή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>&amp;Right</source>
        <translation>&amp;Δεξιά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>&amp;Left</source>
        <translation>&amp;Αριστερά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Διάταξη των καρτελών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>&amp;None</source>
        <translation>&amp;Καμία</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;Διάταξη της γραμμής κύλισης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Κύβος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Απροσδιόριστο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Δοκός</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Σχήμα δρομέα πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>A process is running.</source>
        <translation>Μια διεργασία εκτελείται.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Exit QTerminal</source>
        <translation>Έξοδος του QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Are you sure you want to exit?</source>
        <translation>Θέλετε σίγουρα να εγκαταλείψετε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Ένας ελαφρύς και ισχυρός ανεξαρτήτου πλατφόρμας προσομοιωτής τερματικού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Copyright (C) </source>
        <translation>Πνευματικά δικαιώματα (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>2013-2025</source>
        <translation>2013-2025</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>LXQt Project</source>
        <translation>Έργο LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>Development: </source>
        <translation>Ανάπτυξη: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Ρυθμίσεις τερματικού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="38"/>
        <location filename="../forms/propertiesdialog.ui" line="729"/>
        <source>Behavior</source>
        <translation>Συμπεριφορά</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Συντομεύσεις</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="56"/>
        <source>Dropdown</source>
        <translation>Αναπτυσσόμενη προβολή</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="65"/>
        <source>Bookmarks</source>
        <translation>Σελιδοδείκτες</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="181"/>
        <source>Color scheme</source>
        <translation>Χρωματικός συνδυασμός</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Widget style</source>
        <translation>Ύφος συστατικού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="207"/>
        <source>Scrollbar position</source>
        <translation>Θέση της γραμμής κύλισης</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>Tabs position</source>
        <translation>Θέση καρτελών</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="512"/>
        <source>Show the menu bar</source>
        <translation>Εμφάνιση της γραμμής μενού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="556"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Απόκρυψη της γραμμής καρτελών με μία μόνο καρτέλα</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="287"/>
        <source>Terminal transparency</source>
        <translation>Διαφάνεια του τερματικού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="297"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="370"/>
        <source>Start with preset:</source>
        <translation>Έναρξη με προρύθμιση:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>None (single terminal)</source>
        <translation>Καμία (απλό τερματικό)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="386"/>
        <source>2 terminals horizontally</source>
        <translation>2 τερματικά οριζόντια</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="391"/>
        <source>2 terminals vertically</source>
        <translation>2 τερματικά κάθετα</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="396"/>
        <source>4 terminals</source>
        <translation>4 τερματικά</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="135"/>
        <source>Font</source>
        <translation>Γραμματοσειρά</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="171"/>
        <source>&amp;Change...</source>
        <translation>&amp;Αλλαγή...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="233"/>
        <source>Cursor shape</source>
        <translation>Σχήμα δρομέα</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="270"/>
        <source>Enable bi-directional text support</source>
        <translation>Ενεργοποίηση της υποστήριξης κειμένου διπλής κατεύθυνσης</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="313"/>
        <source>Background image:</source>
        <translation>Εικόνα παρασκηνίου:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Select</source>
        <translation>Επιλογή</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="263"/>
        <source>Show terminal size on resize</source>
        <translation>Εμφάνιση του μεγέθους του τερματικού κατά την αλλαγή μεγέθους του παραθύρου</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="563"/>
        <source>Fixed tab width:</source>
        <translation>Σταθερό πλάτος καρτέλας:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="414"/>
        <location filename="../forms/propertiesdialog.ui" line="573"/>
        <source>px</source>
        <translation>εικ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="536"/>
        <source>Show close button on each tab</source>
        <translation>Εμφάνιση του κουμπιού κλεισίματος σε κάθε καρτέλα</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Terminal margin</source>
        <translation>Περιθώριο τερματικού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="280"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Χρήση των χαρακτήρων σχεδίασης πλαισίου που περιέχονται στην γραμματοσειρά</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="519"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Οι επιταχυντές ενεργοποιούνται με Alt και μπορούν να επιδρούν με το τερματικό.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="522"/>
        <source>No menu bar accelerator</source>
        <translation>Χωρίς επιταχυντή γραμμής μενού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="922"/>
        <source>Emulation</source>
        <translation>Προσομοίωση</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Action after paste</source>
        <translation>Ενέργεια μετά την επικόλληση</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="828"/>
        <source>Confirm multiline paste</source>
        <translation>Επιβεβαίωση επικόλλησης πολλαπλών γραμμών</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="835"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Κλάδεμα των τελικών νέων γραμμών στο επικολλημένο κείμενο</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="849"/>
        <source>Open new terminals in current working directory</source>
        <translation>Άνοιγμα των νέων τερματικών στον τρέχοντα κατάλογο εργασίας</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="590"/>
        <source>Save Size when closing</source>
        <translation>Αποθήκευση του μεγέθους κατά το κλείσιμο</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="583"/>
        <source>Save Position when closing</source>
        <translation>Αποθήκευση της θέσης κατά το κλείσιμο</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Unlimited history</source>
        <translation>Απεριόριστο ιστορικό</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="735"/>
        <source>History size (in lines)</source>
        <translation>Μέγεθος ιστορικού (γραμμές)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="873"/>
        <source>Default $TERM</source>
        <translation>Εξ ορισμού $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="609"/>
        <source>Start with this size:</source>
        <translation>Έναρξη με αυτό το μέγεθος:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="334"/>
        <source>Background mode:</source>
        <translation>Λειτουργία παρασκηνίου:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="342"/>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Stretch</source>
        <translation>Τέντωμα</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="352"/>
        <source>Zoom</source>
        <translation>Εστίαση</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="357"/>
        <source>Fit</source>
        <translation>Προσαρμογή</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="362"/>
        <source>Center</source>
        <translation>Κέντρο</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="277"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Καθορίζει αν οι χαρακτήρες για τον σχεδιασμό του πλαισίου θα σχεδιάζονται εσωτερικά από το QTerminal ή από την υποκείμενη βιβλιοθήκη αποτύπωσης της γραμματοσειράς.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="253"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Εναλλαγή της χρήσης έντονων χαρακτήρων γραμματοσειρών για την αποτύπωση έντονων χρωματισμών</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="256"/>
        <source>Use bold font face for intense colors</source>
        <translation>Χρήση έντονων χαρακτήρων για έντονους χρωματισμούς</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="529"/>
        <source>&amp;Hide Window Borders</source>
        <translation>Απόκρυ&amp;ψη του περιγράμματος του παραθύρου</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Συμπεριφορά προς προσομοίωση Σημειώστε ότι δεν χρειάζεται να συνάδει με το λειτουργικό σύστημα&lt;/p&gt;&lt;p&gt;Αν δεν είστε σίγουρος-η, χρησιμοποιήστε την &lt;span style=&quot; font-weight:600;&quot;&gt;προσομοίωση&lt;/span&gt; default.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Αυτή η εντολή θα εκτελεστεί με ένα όρισμα με το όνομα ενός προσωρινού αρχείου που θα χρησιμοποιηθεί για την καταγραφή του ιστορικού κύλισης</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="912"/>
        <source>Handle history command</source>
        <translation>Εντολή διαχείρισης ιστορικού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="616"/>
        <location filename="../forms/propertiesdialog.ui" line="630"/>
        <source> px</source>
        <translation> εικ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Get current size</source>
        <translation>Λήψη του τρέχοντος μεγέθους</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="859"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Άνοιγμα της νέας καρτέλας δεξιά από την ενεργή καρτέλα</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="856"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Αν δεν είναι επιλεγμένο η νέα καρτέλα θα ανοίγει στην δεξιότερη θέση</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="546"/>
        <source>Close tab on middle-click</source>
        <translation>Κλείσιμο της καρτέλας με μεσαίο κλικ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="821"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Εξαναγκασμός απενεργοποίησης της λειτουργίας επικόλλησης με αγκύλη</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="775"/>
        <source>Word selection characters</source>
        <translation>Χαρακτήρες επιλογής λέξης</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <source>Window</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="246"/>
        <source>Blinking cursor</source>
        <translation>Αναβοσβήνων δρομέας</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="421"/>
        <source>Current Terminal</source>
        <translation>Τρέχον τερματικό</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Draw a border</source>
        <translation>Σχεδίαση περιγράμματος</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="434"/>
        <source>Set the current terminal on mouseover</source>
        <translation>Ορισμός του τρέχοντος τερματικού με το πέρασμα του ποντικιού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="441"/>
        <source>Change window title based on the terminal</source>
        <translation>Αλλαγή του τίτλου του παραθύρου βάσει του τερματικού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="448"/>
        <source>Change window icon based on the terminal</source>
        <translation>Αλλαγή του εικονιδίου του παραθύρου βάσει του τερματικού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="597"/>
        <source>Save State when closing</source>
        <translation>Αποθήκευση της κατάστασης κατά την έξοδο</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>Κατά την επιλογή κειμένου ανά λέξη, εκτός των αλφαριθμητικών χαρακτήρων, να λαμβάνονται υπ΄όψιν και αυτοί οι χαρακτήρες ως μέρος των λέξεων</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="785"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="792"/>
        <source>Mouse cursor hiding delay</source>
        <translation>Καθυστέρηση απόκρυψης του δρομέα του ποντικιού</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="799"/>
        <source>No hiding</source>
        <translation>Δίχως απόκρυψη</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="802"/>
        <source> sec</source>
        <translation> δευτ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="818"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Η λειτουργία επικόλλησης με αγκύλη είναι χρήσιμη κατά την επικόλληση συμβολοσειρών πολλαπλών γραμμών.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="842"/>
        <source>Prompt on closing with a running process</source>
        <translation>Προτροπή κατά το κλείσιμο με μια διεργασία σε εκτέλεση</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="866"/>
        <source>Audible bell</source>
        <translation>Κώδων ήχου</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Για την επεξεργασία μιας συντόμευσης:
1. Κάντε διπλό κλικ στο πλήκτρο της
2. Πιέστε τον επιθυμητό συνδυασμό και αφήστε τον
3. Κάντε κλικ σε μια συντόμευση ή πιέστε Enter

Για την αφαίρεση/απενεργοποίηση μιας συντόμευσης, στο στάδιο 2 πιέστε μόνον έναν τροποποιητή (πχ το Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="985"/>
        <source>Shortcut</source>
        <translation>Συντόμευση</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="990"/>
        <source>Key</source>
        <translation>Συνδυασμός πλήκτρων</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1002"/>
        <source>Show on start</source>
        <translation>Εμφάνιση κατά την έναρξη</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1009"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Ένα κουμπί κλειδώματος εμφανίζεται στην οριζόντια γραμμή καρτελών</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1012"/>
        <source>Keep window open when it loses focus</source>
        <translation>Διατήρηση του παραθύρου ανοιχτό κατά την απώλεια της εστίασης</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1030"/>
        <source>Height</source>
        <translation>Ύψος</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1040"/>
        <location filename="../forms/propertiesdialog.ui" line="1063"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1053"/>
        <source>Width</source>
        <translation>Πλάτος</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1083"/>
        <source>Shortcut:</source>
        <translation>Συντόμευση:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1092"/>
        <source>Note: On Wayland, the shortcut has to be added in the compositor settings for &apos;qterminal -d&apos;.</source>
        <translation>Σημείωση: Στο Wayland, η συντόμευση πρέπει να προστεθεί στις ρυθμίσεις του συνθέτη για το &apos;qterminal -d&apos;.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1160"/>
        <source>Edit bookmark file contents</source>
        <translation>Επεξεργασία των περιεχομένων του αρχείου των σελιδοδεικτών</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1119"/>
        <source>Enable bookmarks</source>
        <translation>Ενεργοποίηση των σελιδοδεικτών</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1128"/>
        <source>Bookmark file</source>
        <translation>Αρχείο των σελιδοδεικτών</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1141"/>
        <source>Find...</source>
        <translation>Αναζήτηση...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1150"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Μπορείτε να καθορίσετε την δική σας τοποθεσία του αρχείου των σελιδοδεικτών. Επιτρέπει εύκολη κοινή χρήση των σελιδοδεικτών με εργαλεία όπως το OwnCloud και το Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <source>No scrollbar</source>
        <translation>Χωρίς γραμμή κύλισης</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Top</source>
        <translation>Κορυφή</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Bottom</source>
        <translation>Βάση</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>BlockCursor</source>
        <translation>Κύβος</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>UnderlineCursor</source>
        <translation>Απροσδιόριστο</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>IBeamCursor</source>
        <translation>Δοκός</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>No move</source>
        <translation>Χωρίς μετάβαση</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to top</source>
        <translation>Κύλιση στην κορυφή</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to bottom</source>
        <translation>Κύλιση στην βάση</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="289"/>
        <source>Examples</source>
        <translation>Παραδείγματα</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="456"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Εικόνες (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="558"/>
        <source>Open bookmarks file</source>
        <translation>Άνοιγμα αρχείου σελιδοδεικτών</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="560"/>
        <source>XML files (*.xml)</source>
        <translation>Αρχεία XML (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="561"/>
        <source>All files (*)</source>
        <translation>Όλα τα αρχεία (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Επιθυμείτε την αντικατάσταση του αρχείου σελιδοδεικτών;</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Το όνομα αρχείου των σελιδοδεικτών δεν έχει την επέκταση &apos;.xml&apos;.
Επιθυμείτε σίγουρα την αντικατάστασή του;</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Warning</source>
        <translation>Προειδοποίηση</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Αδύνατη η εγγραφή των σελιδοδεικτών στο αρχείο:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="225"/>
        <location filename="../propertiesdialog.cpp" line="342"/>
        <source>System Default</source>
        <translation>Συστήματος</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="455"/>
        <source>Choose a background image</source>
        <translation>Επιλογή μιας εικόνας παρασκηνίου</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Συγχρονισμένοι σελιδοδείκτες</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="85"/>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Shell No. %1</source>
        <translation>Κέλυφος ν. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Close Subterminal</source>
        <translation>Κλείσιμο του υποτερματικού</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Are you sure you want to close this subterminal?</source>
        <translation>Επιθυμείτε σίγουρα το κλείσιμο του υποτερματικού;</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="222"/>
        <source>Tab name</source>
        <translation>Όνομα καρτέλας</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>New tab name:</source>
        <translation>Νέο όνομα καρτέλας:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="243"/>
        <source>Select new tab title color</source>
        <translation>Επιλογή χρώματος τίτλου της νέας καρτέλας</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="272"/>
        <source>Close session</source>
        <translation>Κλείσιμο της συνεδρίας</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="274"/>
        <source>Change title color</source>
        <translation>Αλλαγή του χρώματος του τίτλου</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Close tab</source>
        <translation>Κλείσιμο καρτέλας</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Are you sure you want to close this tab?</source>
        <translation>Επιθυμείτε σίγουρα το κλείσιμο της καρτέλας;</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>Φόρτωση συνεδρίας</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>Κατάλογος των αποθηκευμένων συνεδριών:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Κύριο παράθυρο</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="62"/>
        <source>&amp;Session</source>
        <translation>&amp;Συνεδρία</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="70"/>
        <source>&amp;Actions</source>
        <translation>Ε&amp;νέργειες</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="75"/>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="82"/>
        <source>&amp;View</source>
        <translation>Π&amp;ροβολή</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="87"/>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="103"/>
        <source>&amp;About...</source>
        <translation>&amp;Περί...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="108"/>
        <source>About &amp;Qt...</source>
        <translation>Περί την &amp;Qt...</translation>
    </message>
</context>
</TS>
